@@ -6,12 +6,18 @@
 #' @param npar Number of model parameters (\emph{default} is  BC.4)
 #' @param error Error bar (It can be SE - \emph{default}, SD or FALSE)
 #' @param ylab Variable response name (Accepts the \emph{expression}() function)
-#' @param xlab treatments name (Accepts the \emph{expression}() function)
+#' @param xlab Treatments name (Accepts the \emph{expression}() function)
 #' @param theme ggplot2 theme (\emph{default} is theme_bw())
-#' @param legend.position legend position (\emph{default} is "top")
-#' @param r2 coefficient of determination of the mean or all values (\emph{default} is all)
+#' @param legend.position Legend position (\emph{default} is "top")
+#' @param r2 Coefficient of determination of the mean or all values (\emph{default} is all)
 #' @param scale Sets x scale (\emph{default} is none, can be "log")
-#' @param point defines whether you want to plot all points ("all") or only the mean ("mean")
+#' @param point Defines whether you want to plot all points ("all") or only the mean ("mean")
+#' @param width.bar	Bar width
+#' @param textsize Font size
+#' @param pointsize	Shape size
+#' @param linesize	Line size
+#' @param pointshape Format point (default is 21)
+#' @param comment Add text after equation
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details The model function for the Brain-Cousens model (Brain and Cousens, 1989) is
 #' \deqn{ f(x, b,c,d,e,f) = c + \frac{d-c+fx}{1+\exp(b(\log(x)-\log(e)))}}
@@ -57,11 +63,18 @@ BC=function(trat,
             r2="all",
             error="SE",
             point="all",
-            scale="none"){
+            width.bar=NA,
+            scale="none",
+            textsize = 12,
+            pointsize = 4.5,
+            linesize = 0.8,
+            pointshape = 21,
+            comment=NA){
   requireNamespace("ggplot2")
   requireNamespace("drc")
   requireNamespace("crayon")
   ymean=tapply(resp,trat,mean)
+  if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   if(error=="SE"){ysd=tapply(resp,trat,sd)/sqrt(tapply(resp,trat,length))}
   if(error=="SD"){ysd=tapply(resp,trat,sd)}
   if(error=="FALSE"){ysd=0}
@@ -110,6 +123,7 @@ BC=function(trat,
   xp=seq(min(trat),max(trat),length.out = 1000)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))}
+  if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
   predesp=predict(mod)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
@@ -121,21 +135,21 @@ BC=function(trat,
   if(point=="mean"){
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
-                                                 width=0.5)}
+                                                 width=width.bar)}
     graph=graph+
-      geom_point(aes(color="black"),size=4.5,shape=21,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   if(point=="all"){
     graph=ggplot(data.frame(trat,resp),aes(x=trat,y=resp))
     graph=graph+
-      geom_point(aes(color="black"),size=4.5,shape=21,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   graph=graph+theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=0.8)+
+                                color="black"),size=linesize)+
     scale_color_manual(name="",values=1,label=parse(text = equation))+
-    theme(axis.text = element_text(size=12,color="black"),
+    theme(axis.text = element_text(size=textsize,color="black"),
           legend.position = legend.position,
-          legend.text = element_text(size=12),
+          legend.text = element_text(size=textsize),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)+
