@@ -12,6 +12,12 @@
 #' @param r2 coefficient of determination of the mean or all values (\emph{default} is all)
 #' @param scale Sets x scale (\emph{default} is none, can be "log")
 #' @param point defines whether you want to plot all points ("all") or only the mean ("mean")
+#' @param width.bar	Bar width
+#' @param textsize Font size
+#' @param pointsize	shape size
+#' @param linesize	line size
+#' @param pointshape format point (default is 21)
+#' @param comment Add text after equation
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); largest and smallest estimated value and the graph using ggplot2 with the equation automatically.
 #' @details The four-parameter model is given by the expression:
 #'
@@ -43,7 +49,14 @@ CD=function(trat,
             error="SE",
             r2="all",
             point="all",
-            scale="none"){
+            width.bar=NA,
+            scale="none",
+            textsize = 12,
+            pointsize = 4.5,
+            linesize = 0.8,
+            pointshape = 21,
+            comment=NA){
+  if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   requireNamespace("ggplot2")
   requireNamespace("drc")
   requireNamespace("crayon")
@@ -74,7 +87,7 @@ CD=function(trat,
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))
   }
-  if(npar=="CRS.5"){mod=drm(resp~trat,fct=LL.5())
+  if(npar=="CRS.5"){mod=drm(resp~trat,fct=CRS.5a())
   coef=summary(mod)
   b=coef$coefficients[,1][1]
   c=coef$coefficients[,1][2]
@@ -97,6 +110,7 @@ CD=function(trat,
   xp=seq(min(trat),max(trat),length.out = 1000)
   preditos=data.frame(x=xp,
                       y=predict(mod,newdata = data.frame(trat=xp)))}
+  if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
   predesp=predict(mod)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
@@ -107,17 +121,17 @@ CD=function(trat,
   data1=data.frame(trat=xmean,resp=ymean)
   graph=ggplot(data,aes(x=xmean,y=ymean))
   if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
-                                               width=0.5)}
+                                               width=width.bar)}
   graph=graph+
-    geom_point(aes(color="black"),size=4.5,shape=21,fill="gray")+
+    geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")+
     theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=0.8)+
+                                color="black"),size=linesize)+
     scale_color_manual(name="",values=1,label=parse(text = equation))+
-    theme(axis.text = element_text(size=12,color="black"),
+    theme(axis.text = element_text(size=textsize,color="black"),
           legend.position = legend.position,
-          legend.text = element_text(size=12),
+          legend.text = element_text(size=textsize),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)+
