@@ -11,6 +11,12 @@
 #' @param r2 coefficient of determination of the mean or all values (\emph{default} is all)
 #' @param point defines whether you want to plot all points ("all") or only the mean ("mean")
 #' @param scale Sets x scale (\emph{default} is none, can be "log")
+#' @param width.bar	Bar width
+#' @param textsize Font size
+#' @param pointsize	shape size
+#' @param linesize	line size
+#' @param pointshape format point (default is 21)
+#' @param comment Add text after equation
 #' @return The function returns a list containing the coefficients and their respective values of p; statistical parameters such as AIC, BIC, pseudo-R2, RMSE (root mean square error); breakpoint and the graph using ggplot2 with the equation automatically.
 #' @export
 #' @author Gabriel Danilo Shimizu
@@ -22,10 +28,10 @@
 #' @details
 #' The linear-plateau model is defined by:
 #' First curve:
-#' \deqn{f(x) = b0+b1*x (x<breakpoint)}
+#' \deqn{f(x) = \beta_0 + \beta_1 \times x (x < breakpoint)}
 #'
 #' Second curve:
-#' \deqn{f(x) = b0+b1*breakpoint (x>breakpoint)}
+#' \deqn{f(x) = \beta_0 + \beta_1 \times breakpoint (x > breakpoint)}
 #' @examples
 #' library(AgroReg)
 #' data("granada")
@@ -40,7 +46,14 @@ linear.plateau=function(trat,resp,
                       error="SE",
                       r2="all",
                       point="all",
-                      scale="none"){
+                      width.bar=NA,
+                      scale="none",
+                      textsize = 12,
+                      pointsize = 4.5,
+                      linesize = 0.8,
+                      pointshape = 21,
+                      comment=NA){
+  if(is.na(width.bar)==TRUE){width.bar=0.01*mean(trat)}
   lp <- function(x, a, b, c) {
     if_else(condition = x < c,
             true = a + b * x,
@@ -88,6 +101,7 @@ linear.plateau=function(trat,resp,
                r2)
 
   equation=s
+  if(is.na(comment)==FALSE){equation=paste(equation,"~\"",comment,"\"")}
   predesp=predict(lp_model)
   predobs=resp
   rmse=sqrt(mean((predesp-predobs)^2))
@@ -97,13 +111,13 @@ linear.plateau=function(trat,resp,
   if(point=="mean"){
     graph=ggplot(data,aes(x=xmean,y=ymean))
     if(error!="FALSE"){graph=graph+geom_errorbar(aes(ymin=ymean-ysd,ymax=ymean+ysd),
-                                                 width=0.5)}
+                                                 width=width.bar)}
     graph=graph+
-      geom_point(aes(color="black"),size=4.5,shape=21,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   if(point=="all"){
     graph=ggplot(data.frame(trat,resp),aes(x=trat,y=resp))
     graph=graph+
-      geom_point(aes(color="black"),size=4.5,shape=21,fill="gray")}
+      geom_point(aes(color="black"),size=pointsize,shape=pointshape,fill="gray")}
   xp=seq(min(trat),max(trat),length=1000)
   yp=predict(lp_model,newdata=data.frame(trat=xp))
   preditos=data.frame(x=xp,y=yp)
@@ -114,11 +128,11 @@ linear.plateau=function(trat,resp,
   graph=graph+theme+
     geom_line(data=preditos,aes(x=x,
                                 y=y,
-                                color="black"),size=0.8)+
+                                color="black"),size=linesize)+
     scale_color_manual(name="",values="black",label=parse(text = equation))+
-    theme(axis.text = element_text(size=12,color="black"),
+    theme(axis.text = element_text(size=textsize,color="black"),
           legend.position = legend.position,
-          legend.text = element_text(size=12),
+          legend.text = element_text(size=textsize),
           legend.direction = "vertical",
           legend.text.align = 0,
           legend.justification = 0)+
